class ScrapingantClientException(Exception):
    """Base class for errors specific to the ScrapingAnt Client."""
    pass


class ScrapingantInvalidTokenException(ScrapingantClientException):
    def __init__(self):
        message = 'API token is wrong or you have exceeded the API calls request limit'
        super().__init__(message)


class ScrapingantInvalidInputException(ScrapingantClientException):
    pass


class ScrapingantInternalException(ScrapingantClientException):
    def __init__(self):
        message = 'Something went wrong with the server side. Please try later or contact support'
        super().__init__(message)



import pytest
import responses

from scrapingant_client import (
    ScrapingAntClient,
    ScrapingantInvalidTokenException,
    ScrapingantInvalidInputException,
    ScrapingantInternalException,
)
from scrapingant_client.constants import SCRAPINGANT_API_BASE_URL


@responses.activate
def test_invalid_token():
    responses.add(responses.POST, SCRAPINGANT_API_BASE_URL + '/general',
                  json={'detail': 'wrong token'}, status=403)
    client = ScrapingAntClient(token='invalid_token')
    with pytest.raises(ScrapingantInvalidTokenException):
        client.general_request('example.com')


@responses.activate
def test_invalid_input():
    responses.add(responses.POST, SCRAPINGANT_API_BASE_URL + '/general',
                  json={'detail': 'wrong url'}, status=422)
    client = ScrapingAntClient(token='some_token')
    with pytest.raises(ScrapingantInvalidInputException) as e:
        client.general_request('bad_url')
    assert '{"detail": "wrong url"}' in str(e)


@responses.activate
def test_internal_server_error():
    responses.add(responses.POST, SCRAPINGANT_API_BASE_URL + '/general',
                  json={}, status=500)
    client = ScrapingAntClient(token='some_token')
    with pytest.raises(ScrapingantInternalException):
        client.general_request('bad_url')



from scrapingant_client import Cookie
from scrapingant_client.cookie import cookies_list_to_string, cookies_list_from_string


def test_cookies_list_to_string_empty():
    assert cookies_list_to_string([]) == ''


def test_cookies_list_to_string():
    cookies = [
        Cookie(
            name='test_name1',
            value='test_value1'
        ),
        Cookie(
            name='test_name2',
            value='test_value2'
        ),
    ]
    assert cookies_list_to_string(cookies) == 'test_name1=test_value1;test_name2=test_value2'


def test_cookies_list_from_string_empty():
    assert cookies_list_from_string('') == []


def test_cookies_list_from_string():
    actual = cookies_list_from_string('test_name1=test_value1;test_name2=test_value2')
    expected = [
        Cookie(
            name='test_name1',
            value='test_value1'
        ),
        Cookie(
            name='test_name2',
            value='test_value2'
        ),
    ]
    assert actual == expected



from enum import Enum

SCRAPINGANT_API_BASE_URL = 'https://api.scrapingant.com/v1'


class ProxyCountry(str, Enum):
    brasilia = 'br'
    china = 'cn'
    germany = 'de'
    spain = 'es'
    france = 'fr'
    the_united_kingdom = 'gb'
    hong_kong = 'hk'
    india = 'in'
    italy = 'it'
    israel = 'il'
    japan = 'jp'
    the_netherlands = 'nl'
    russia = 'ru'
    saudi_arabia = 'sa'
    the_united_arab_emirates = 'ae'
    usa = 'us'
